@@ -1,4 +1,4 @@
-from typing import Tuple, Dict, List, Any
+from typing import Tuple, Dict, List, Any, Union
 import os
 import json
 import numpy as np
@@ -92,16 +92,23 @@ class DataReader:
                 return i
         raise RuntimeError("Encountered no filament particles! Something is wrong.")
 
-    def get_filaments(self, frame_idx: int) -> Tuple[List[Filament], LinksArray]:
+    def get_non_filament_coordinates(self, minimum_image: bool) -> np.ndarray:
+        pos = self.read_particle_positions(minimum_image)
+        offset = self.get_n_non_filament_particles()
+        return pos[:, :offset]
+
+    def get_filaments(
+            self,
+            frame_idx: int
+    ) -> Tuple[List[Filament], Union[LinksArray, None]]:
         """
         Get filaments at frame ``frame_idx``. Can't handle simulations that were
         split into parts. For split simulations use DataReader.get_filaments_all
         instead.
         """
         if self.parts:
-            msg = "This method can't be used for simulation data split into parts. "
-            msg += "Use DataReader.get_filaments_all instead."
-            raise RuntimeError(msg)
+            fil = self.get_filaments_all()[frame_idx]
+            return fil, None
         return self._get_filaments(frame_idx)
 
     def _get_filaments(self, t_idx: int) -> Tuple[List[Filament], LinksArray]:
@@ -288,7 +295,17 @@ class DataReader:
         return self._read_dataset_from_filaments_group(dataset_name, frame)
 
     def _read_dataset_from_filaments_group(self, dataset_name: str, frame: int) -> np.ndarray:
-        with h5py.File(self.links_file, 'r') as h5f:
+        """
+        From links file, access the group 'filaments' and retrieve given dataset.
+        """
+        if self.parts:
+            n = self._read_n_frames_per_part()
+            p = frame // n
+            frame = frame % n
+            links_file = self.links_file.format(p)
+        else:
+            links_file = self.links_file
+        with h5py.File(links_file, 'r') as h5f:
             group = h5f['filaments']
             k0 = list(group.keys())[0]
             template = "{:0" + str(len(k0)) + "}"
