@@ -8,12 +8,11 @@ from .periodic_boundaries import get_minimum_image_vector
 
 Topology = readdy._internal.readdybinding.api.top.Topology
 Particle = readdy._internal.readdybinding.common.Particle
-Vertex   = readdy._internal.readdybinding.api.top.Vertex
+Vertex = readdy._internal.readdybinding.api.top.Vertex
 RDSystem = readdy.ReactionDiffusionSystem
 
 
 class FilamentHandler:
-
     """
     Keeps track of filaments and their beads. Needs to be carefully initialized
     before any simulation! The order of how you add particles to your simulation
@@ -68,11 +67,11 @@ class FilamentHandler:
         if k_stretch < 1e-15:
             self.sigma_length = 2
         else:
-            self.sigma_length = np.sqrt(1/k_stretch)
+            self.sigma_length = np.sqrt(1 / k_stretch)
         if k_bend < 1e-15:
-            self.sigma_angle = 2*np.pi
+            self.sigma_angle = 2 * np.pi
         else:
-            self.sigma_angle = np.sqrt(1/k_bend)
+            self.sigma_angle = np.sqrt(1 / k_bend)
         self.n_beads_total = 0
         self._index_offset = 0
         self._n_non_filament_particles = 0
@@ -138,6 +137,17 @@ class FilamentHandler:
         FilamentHandler._global_n_beads_total += 1
         self._n_non_filament_particles += 1
 
+    def add_non_filament_particle_number(self, n: int):
+        if self.n_beads_total != 0:
+            msg = "FilamentHandler already contains filaments. "
+            msg += "You need to add all non-filament particles before initializing "
+            msg += "setting information on filaments!\n"
+            msg += "Make all calls to FilamentHandler.add_non_filament_particle "
+            msg += "before calling FilamentHandler.initialize ."
+            raise RuntimeError(msg)
+        FilamentHandler._global_n_beads_total += n
+        self._n_non_filament_particles += n
+
     def update(
             self,
             reaction_counts: Union[Tuple[Dict[str, int], Dict[str, int],
@@ -205,7 +215,7 @@ class FilamentHandler:
 
         map_pid_to_vid = self._build_map_particle_id_to_vertex_index(topology)
         motor_id = motors[
-          np.random.choice(len(motors))
+            np.random.choice(len(motors))
         ]
         fwd_neighbor_id = self.links[motor_id, 1]
         if self.links[fwd_neighbor_id, 1] == -1:
@@ -238,7 +248,6 @@ class FilamentHandler:
         r = max(rate * (1 - self._n_motors / n_max_motors), 0.0)
         return r
 
-
     def reaction_function_motor_unbind(self, topology):
         recipe = readdy.StructuralReactionRecipe(topology)
         top_id = self._get_topology_id(topology)
@@ -265,7 +274,7 @@ class FilamentHandler:
                 _v2 = topology.position_of_vertex(vertices[map_pid_to_vid[p[1]]])
                 v = self._get_minimum_image_vector_between_motor_pair(_v1, _v2)
                 distances[i] = v
-            distances = np.sqrt((distances**2).sum(1))
+            distances = np.sqrt((distances ** 2).sum(1))
             idx = self._get_distance_weighted_random_index(distances)
             selected_pair = list(motor_pairs)[idx]
 
@@ -356,9 +365,9 @@ class FilamentHandler:
         for v in topology.get_graph().get_vertices():
             pids.append(topology.particle_id_of_vertex(v))
             pids_min_offset.append(topology.particle_id_of_vertex(v) - self._index_offset)
-            if topology.particle_id_of_vertex(v)-self._index_offset == next_id:
+            if topology.particle_id_of_vertex(v) - self._index_offset == next_id:
                 next_position = topology.position_of_vertex(v)
-            if topology.particle_id_of_vertex(v)-self._index_offset == head_id:
+            if topology.particle_id_of_vertex(v) - self._index_offset == head_id:
                 head_position = topology.position_of_vertex(v)
                 head_vertex = v
             if next_position is None:
@@ -384,10 +393,10 @@ class FilamentHandler:
         for i in range(3):
             head_pos[i] = head_position[i]
             next_pos[0, i] = next_position[i]
-        direction = get_minimum_image_vector(head_pos + self.box/2,
-                                             next_pos + self.box/2,
+        direction = get_minimum_image_vector(head_pos + self.box / 2,
+                                             next_pos + self.box / 2,
                                              self.box)[0]
-        direction = direction / np.sqrt(np.sum(direction**2))
+        direction = direction / np.sqrt(np.sum(direction ** 2))
         length = np.random.randn() * self.sigma_length + 1
         angle = np.random.randn() * self.sigma_angle
         gamma = np.random.rand() * np.pi
@@ -406,7 +415,7 @@ class FilamentHandler:
 
         return recipe
 
-    def write(self, particles, ndigits_t: int=5):
+    def write(self, particles, ndigits_t: int = 5):
         """
         Write current state of filaments (which beads belong to which filaments,
         defined via links between filamentous beads) to a HDF5 file.
@@ -442,7 +451,7 @@ class FilamentHandler:
                 assert self.links[idx, 1] != -1
                 assert self.links[idx, 2] == -1, 'idx = {}; links[{}, 2] = {}'.format(
                     idx, idx, self.links[idx, 2]
-                )                
+                )
             else:
                 continue
             bead_types[idx] = FilamentHandler.enum_map[t]
@@ -468,7 +477,7 @@ class FilamentHandler:
         m = {}
         vertices = topology.get_graph().get_vertices()
         for i, v in enumerate(vertices):
-            m[topology.particle_id_of_vertex(v)-self._index_offset] = i # v.particle_index
+            m[topology.particle_id_of_vertex(v) - self._index_offset] = i  # v.particle_index
         return m
 
     def _get_topology_id(self, topology) -> int:
