@@ -1,3 +1,4 @@
+from abc import ABC, abstractmethod
 from typing import Dict, Any, Union
 import os
 import json
@@ -313,7 +314,7 @@ class _AcceptanceRateHandlerDefault:
         return {'type': 'default'}
 
 
-class AcceptanceRateHandlerPotential:
+class AcceptanceRateHandlerPotential(ABC):
     """
     Base class for potentials during network generation.
     The methods ``AcceptanceRateHandlerPotential.energy`` and
@@ -331,8 +332,18 @@ class AcceptanceRateHandlerPotential:
     def __init__(self, n_batch: int):
         self.n_batch = n_batch
 
+    @abstractmethod
     def energy(self, coords: np.ndarray) -> np.ndarray:
-        raise NotImplementedError
+        """
+        Compute energy for each of the N positions in array ``coords``.
+        For each position, a scalar energy has to be computed, leading to
+        an array of length N as return value.
+        This method has to be overwritten in child classes.
+
+        :param coords: Array of possible coordinates of shape (N, 3).
+        :return: Array of energies of shape (N,).
+        """
+        ...
 
     def __call__(self, possible_coords: np.ndarray) -> np.ndarray:
         exp_energy = np.exp(-self.energy(possible_coords))
@@ -346,8 +357,16 @@ class AcceptanceRateHandlerPotential:
                                       replace=False, p=p[valid])
         return possible_coords[idx_chosen]
 
+    @abstractmethod
     def get_config_as_dict(self) -> Dict[str, Any]:
-        raise NotImplementedError
+        """
+        Convert the parameters that define this instance of
+        ``AcceptanceRateHandlerPotential`` to a dictionary that
+        can be written as json (i.e. the dict may only contain built-in python
+        types like dicts, lists, strings, floats, integers, booleans).
+        This is an abstract method that has to be overwritten in child classes.
+        """
+        ...
 
 
 class AcceptanceRateHandlerBeadInNetwork(AcceptanceRateHandlerPotential):
